@@ -2,8 +2,12 @@
 """API model for working with system configuration."""
 from ...exceptions import ApiError, NotFoundError
 from ..mixins import ChildMixins
-from ..parsers.config import (config_build, config_unchanged, config_unknown,
-                              parse_settings)
+from ..parsers.config import (
+    config_build,
+    config_unchanged,
+    config_unknown,
+    parse_settings,
+)
 from ..parsers.tables import tablize
 
 
