@@ -1,8 +1,15 @@
 # -*- coding: utf-8 -*-
 """Command line interface for Axonius API Client."""
 from ..context import CONTEXT_SETTINGS, click
-from ..options import (AUTH, EXPORT, FIELDS_SELECT, PAGING, SQ_NAME,
-                       add_options, get_option_help)
+from ..options import (
+    AUTH,
+    EXPORT,
+    FIELDS_SELECT,
+    PAGING,
+    SQ_NAME,
+    add_options,
+    get_option_help,
+)
 from .grp_common import GET_EXPORT
 
 METHOD = "get-by-saved-query"
