@@ -3,8 +3,15 @@
 import click
 
 from ..context import AliasedGroup
-from . import (grp_central_core, grp_discover, grp_meta, grp_nodes, grp_roles,
-               grp_settings, grp_users)
+from . import (
+    grp_central_core,
+    grp_discover,
+    grp_meta,
+    grp_nodes,
+    grp_roles,
+    grp_settings,
+    grp_users,
+)
 
 
 @click.group(cls=AliasedGroup)
