@@ -3,7 +3,7 @@
 import click
 
 from ...context import AliasedGroup
-from . import cmd_add, cmd_delete, cmd_get, cmd_get_default, cmd_set_default, cmd_update
+from . import cmd_add, cmd_delete, cmd_get, cmd_get_by_name, cmd_update
 
 
 @click.group(cls=AliasedGroup)
@@ -12,8 +12,7 @@ def roles():
 
 
 roles.add_command(cmd_get.cmd)
-roles.add_command(cmd_get_default.cmd)
-roles.add_command(cmd_set_default.cmd)
+roles.add_command(cmd_get_by_name.cmd)
 roles.add_command(cmd_delete.cmd)
 roles.add_command(cmd_add.cmd)
 roles.add_command(cmd_update.cmd)
